"""
NOVA: The Prompt Pattern Matching
Author: Thomas Roccia 
twitter: @fr0gger_
License: MIT License
Version: 1.0.0
Description: Utility functions for Nova framework
"""

from nova.utils.config import NovaConfig, get_config

__all__ = [
    'NovaConfig',
    'get_config',
]